@@ -1,7 +1,7 @@
 /*
  * MP3/MPlayer plugin to VDR (C++)
  *
- * (C) 2001,2004 Stefan Huelswitt <s.huelswitt@gmx.de>
+ * (C) 2001-2010 Stefan Huelswitt <s.huelswitt@gmx.de>
  *
  * This code is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,6 +19,8 @@
  * Or, point your browser to http://www.gnu.org/copyleft/gpl.html
  */
 
+#include <string.h>
+
 #include "common.h"
 #include "setup-mplayer.h"
 
@@ -28,7 +30,12 @@ cMPlayerSetup MPlayerSetup;
 
 cMPlayerSetup::cMPlayerSetup(void)
 {
-  SlaveMode = 0;
-  DisableResume = 0;
+  SlaveMode = 1;
+  ResumeMode = 2;
   HideMainMenu = 0;
+  PrevNextKeyMode = 0;
+  memset(KeyCmd,0,sizeof(KeyCmd));
+  strcpy(KeyCmd[1],"audio_delay +0.1");
+  strcpy(KeyCmd[7],"audio_delay -0.1");
+  strcpy(KeyCmd[4],"switch_audio");
 }
